#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.notification_plugin_settings_ui"), aligned (sizeof(void *) > 8 ? sizeof(void *) : 8)))
#else
# define SECTION
#endif

static const SECTION union { const guint8 data[14753]; const double alignment; void * const ptr;}  notification_plugin_settings_ui_resource_data = {
  "\107\126\141\162\151\141\156\164\000\000\000\000\000\000\000\000"
  "\030\000\000\000\310\000\000\000\000\000\000\050\006\000\000\000"
  "\000\000\000\000\000\000\000\000\002\000\000\000\004\000\000\000"
  "\004\000\000\000\005\000\000\000\113\120\220\013\003\000\000\000"
  "\310\000\000\000\004\000\114\000\314\000\000\000\320\000\000\000"
  "\363\320\363\212\005\000\000\000\320\000\000\000\042\000\166\000"
  "\370\000\000\000\156\071\000\000\240\124\352\031\000\000\000\000"
  "\156\071\000\000\005\000\114\000\164\071\000\000\170\071\000\000"
  "\324\265\002\000\377\377\377\377\170\071\000\000\001\000\114\000"
  "\174\071\000\000\200\071\000\000\114\071\313\001\002\000\000\000"
  "\200\071\000\000\010\000\114\000\210\071\000\000\214\071\000\000"
  "\107\356\125\301\004\000\000\000\214\071\000\000\015\000\114\000"
  "\234\071\000\000\240\071\000\000\157\162\147\057\002\000\000\000"
  "\156\157\164\151\146\151\143\141\164\151\157\156\055\160\154\165"
  "\147\151\156\055\163\145\164\164\151\156\147\163\056\147\154\141"
  "\144\145\000\000\000\000\000\000\146\070\000\000\000\000\000\000"
  "\074\077\170\155\154\040\166\145\162\163\151\157\156\075\042\061"
  "\056\060\042\040\145\156\143\157\144\151\156\147\075\042\125\124"
  "\106\055\070\042\077\076\012\074\041\055\055\040\107\145\156\145"
  "\162\141\164\145\144\040\167\151\164\150\040\147\154\141\144\145"
  "\040\063\056\064\060\056\060\040\055\055\076\012\074\151\156\164"
  "\145\162\146\141\143\145\076\012\040\040\074\162\145\161\165\151"
  "\162\145\163\040\154\151\142\075\042\147\164\153\053\042\040\166"
  "\145\162\163\151\157\156\075\042\063\056\062\064\042\057\076\012"
  "\040\040\074\157\142\152\145\143\164\040\143\154\141\163\163\075"
  "\042\107\164\153\111\155\141\147\145\042\040\151\144\075\042\151"
  "\155\141\147\145\061\042\076\012\040\040\040\040\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\166\151\163\151"
  "\142\154\145\042\076\124\162\165\145\074\057\160\162\157\160\145"
  "\162\164\171\076\012\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\143\141\156\055\146\157\143"
  "\165\163\042\076\106\141\154\163\145\074\057\160\162\157\160\145"
  "\162\164\171\076\012\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\151\143\157\156\055\156\141"
  "\155\145\042\076\150\145\154\160\055\142\162\157\167\163\145\162"
  "\074\057\160\162\157\160\145\162\164\171\076\012\040\040\074\057"
  "\157\142\152\145\143\164\076\012\040\040\074\157\142\152\145\143"
  "\164\040\143\154\141\163\163\075\042\107\164\153\111\155\141\147"
  "\145\042\040\151\144\075\042\151\155\141\147\145\062\042\076\012"
  "\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\166\151\163\151\142\154\145\042\076\124\162\165"
  "\145\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\143\141\156\055\146\157\143\165\163\042\076\106\141\154\163"
  "\145\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\151\143\157\156\055\156\141\155\145\042\076\167\151\156\144"
  "\157\167\055\143\154\157\163\145\055\163\171\155\142\157\154\151"
  "\143\074\057\160\162\157\160\145\162\164\171\076\012\040\040\074"
  "\057\157\142\152\145\143\164\076\012\040\040\074\157\142\152\145"
  "\143\164\040\143\154\141\163\163\075\042\107\164\153\101\144\152"
  "\165\163\164\155\145\156\164\042\040\151\144\075\042\154\157\147"
  "\137\144\151\163\160\154\141\171\137\154\151\155\151\164\137\141"
  "\144\152\042\076\012\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\165\160\160\145\162\042\076"
  "\061\060\060\074\057\160\162\157\160\145\162\164\171\076\012\040"
  "\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\166\141\154\165\145\042\076\061\060\074\057\160\162"
  "\157\160\145\162\164\171\076\012\040\040\040\040\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\163\164\145\160"
  "\055\151\156\143\162\145\155\145\156\164\042\076\061\074\057\160"
  "\162\157\160\145\162\164\171\076\012\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\160\141\147"
  "\145\055\151\156\143\162\145\155\145\156\164\042\076\065\074\057"
  "\160\162\157\160\145\162\164\171\076\012\040\040\074\057\157\142"
  "\152\145\143\164\076\012\040\040\074\157\142\152\145\143\164\040"
  "\143\154\141\163\163\075\042\107\164\153\101\144\152\165\163\164"
  "\155\145\156\164\042\040\151\144\075\042\154\157\147\137\151\143"
  "\157\156\137\163\151\172\145\137\141\144\152\042\076\012\040\040"
  "\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\154\157\167\145\162\042\076\070\074\057\160\162\157\160"
  "\145\162\164\171\076\012\040\040\040\040\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\165\160\160\145\162\042"
  "\076\062\065\066\074\057\160\162\157\160\145\162\164\171\076\012"
  "\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\166\141\154\165\145\042\076\063\062\074\057\160"
  "\162\157\160\145\162\164\171\076\012\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\163\164\145"
  "\160\055\151\156\143\162\145\155\145\156\164\042\076\061\074\057"
  "\160\162\157\160\145\162\164\171\076\012\040\040\040\040\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\160\141"
  "\147\145\055\151\156\143\162\145\155\145\156\164\042\076\070\074"
  "\057\160\162\157\160\145\162\164\171\076\012\040\040\074\057\157"
  "\142\152\145\143\164\076\012\040\040\074\157\142\152\145\143\164"
  "\040\143\154\141\163\163\075\042\107\164\153\104\151\141\154\157"
  "\147\042\040\151\144\075\042\163\145\164\164\151\156\147\163\137"
  "\144\151\141\154\157\147\042\076\012\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\143\141\156"
  "\055\146\157\143\165\163\042\076\106\141\154\163\145\074\057\160"
  "\162\157\160\145\162\164\171\076\012\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\164\151\164"
  "\154\145\042\040\164\162\141\156\163\154\141\164\141\142\154\145"
  "\075\042\171\145\163\042\076\116\157\164\151\146\151\143\141\164"
  "\151\157\156\040\120\154\165\147\151\156\040\123\145\164\164\151"
  "\156\147\163\074\057\160\162\157\160\145\162\164\171\076\012\040"
  "\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\167\151\156\144\157\167\055\160\157\163\151\164\151"
  "\157\156\042\076\143\145\156\164\145\162\074\057\160\162\157\160"
  "\145\162\164\171\076\012\040\040\040\040\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\144\145\163\164\162\157"
  "\171\055\167\151\164\150\055\160\141\162\145\156\164\042\076\124"
  "\162\165\145\074\057\160\162\157\160\145\162\164\171\076\012\040"
  "\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\151\143\157\156\055\156\141\155\145\042\076\157\162"
  "\147\056\170\146\143\145\056\156\157\164\151\146\151\143\141\164"
  "\151\157\156\074\057\160\162\157\160\145\162\164\171\076\012\040"
  "\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\164\171\160\145\055\150\151\156\164\042\076\144\151"
  "\141\154\157\147\074\057\160\162\157\160\145\162\164\171\076\012"
  "\040\040\040\040\074\143\150\151\154\144\040\151\156\164\145\162"
  "\156\141\154\055\143\150\151\154\144\075\042\166\142\157\170\042"
  "\076\012\040\040\040\040\040\040\074\157\142\152\145\143\164\040"
  "\143\154\141\163\163\075\042\107\164\153\102\157\170\042\076\012"
  "\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\143\141\156\055\146\157\143\165"
  "\163\042\076\106\141\154\163\145\074\057\160\162\157\160\145\162"
  "\164\171\076\012\040\040\040\040\040\040\040\040\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\157\162\151\145"
  "\156\164\141\164\151\157\156\042\076\166\145\162\164\151\143\141"
  "\154\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\163\160\141\143\151\156\147\042\076\062\074"
  "\057\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040"
  "\040\040\040\074\143\150\151\154\144\040\151\156\164\145\162\156"
  "\141\154\055\143\150\151\154\144\075\042\141\143\164\151\157\156"
  "\137\141\162\145\141\042\076\012\040\040\040\040\040\040\040\040"
  "\040\040\074\157\142\152\145\143\164\040\143\154\141\163\163\075"
  "\042\107\164\153\102\165\164\164\157\156\102\157\170\042\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\143\141\156\055"
  "\146\157\143\165\163\042\076\106\141\154\163\145\074\057\160\162"
  "\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\154\141\171\157\165\164\055\163\164\171\154\145"
  "\042\076\145\156\144\074\057\160\162\157\160\145\162\164\171\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\074\143\150"
  "\151\154\144\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\157\142\152\145\143\164\040\143\154\141\163\163"
  "\075\042\107\164\153\102\165\164\164\157\156\042\040\151\144\075"
  "\042\150\145\154\160\137\142\165\164\164\157\156\042\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\154"
  "\141\142\145\154\042\040\164\162\141\156\163\154\141\164\141\142"
  "\154\145\075\042\171\145\163\042\076\137\110\145\154\160\074\057"
  "\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\166\151\163\151\142\154"
  "\145\042\076\124\162\165\145\074\057\160\162\157\160\145\162\164"
  "\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\143\141\156\055\146\157\143\165\163\042\076\124\162"
  "\165\145\074\057\160\162\157\160\145\162\164\171\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\162\145"
  "\143\145\151\166\145\163\055\144\145\146\141\165\154\164\042\076"
  "\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\151\155\141\147\145\042\076\151\155\141\147\145\061\074\057\160"
  "\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\165\163\145\055\165\156\144"
  "\145\162\154\151\156\145\042\076\124\162\165\145\074\057\160\162"
  "\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\057\157\142\152\145\143\164\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160"
  "\141\143\153\151\156\147\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\145\170\160\141\156\144\042\076"
  "\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\146\151\154\154\042\076\124\162\165\145\074\057\160\162\157\160"
  "\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\160\157\163\151\164\151\157\156\042\076"
  "\060\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\074\057\160\141\143"
  "\153\151\156\147\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\057\143\150\151\154\144\076\012\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\143\150\151\154\144\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\074\157\142"
  "\152\145\143\164\040\143\154\141\163\163\075\042\107\164\153\102"
  "\165\164\164\157\156\042\040\151\144\075\042\143\154\157\163\145"
  "\137\142\165\164\164\157\156\042\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\154\141\142\145\154\042"
  "\040\164\162\141\156\163\154\141\164\141\142\154\145\075\042\171"
  "\145\163\042\076\137\103\154\157\163\145\074\057\160\162\157\160"
  "\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\166\151\163\151\142\154\145\042\076\124"
  "\162\165\145\074\057\160\162\157\160\145\162\164\171\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\143"
  "\141\156\055\146\157\143\165\163\042\076\124\162\165\145\074\057"
  "\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\143\141\156\055\144\145"
  "\146\141\165\154\164\042\076\124\162\165\145\074\057\160\162\157"
  "\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\162\145\143\145\151\166\145\163\055"
  "\144\145\146\141\165\154\164\042\076\124\162\165\145\074\057\160"
  "\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\151\155\141\147\145\042\076"
  "\151\155\141\147\145\062\074\057\160\162\157\160\145\162\164\171"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\165\163\145\055\165\156\144\145\162\154\151\156\145\042"
  "\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\057\157\142\152\145\143\164\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\160\141\143\153\151\156\147\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\145\170\160\141\156\144\042\076\124\162\165\145\074\057\160"
  "\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\146\151\154\154\042\076\124"
  "\162\165\145\074\057\160\162\157\160\145\162\164\171\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\160"
  "\157\163\151\164\151\157\156\042\076\061\074\057\160\162\157\160"
  "\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\057\160\141\143\153\151\156\147\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\074\057\143\150\151"
  "\154\144\076\012\040\040\040\040\040\040\040\040\040\040\074\057"
  "\157\142\152\145\143\164\076\012\040\040\040\040\040\040\040\040"
  "\040\040\074\160\141\143\153\151\156\147\076\012\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\145\170\160\141\156\144\042\076"
  "\106\141\154\163\145\074\057\160\162\157\160\145\162\164\171\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\146\151\154"
  "\154\042\076\106\141\154\163\145\074\057\160\162\157\160\145\162"
  "\164\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\160\157\163\151\164\151\157\156\042\076\060\074\057\160\162\157"
  "\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040"
  "\040\074\057\160\141\143\153\151\156\147\076\012\040\040\040\040"
  "\040\040\040\040\074\057\143\150\151\154\144\076\012\040\040\040"
  "\040\040\040\040\040\074\143\150\151\154\144\076\012\040\040\040"
  "\040\040\040\040\040\040\040\074\041\055\055\040\156\055\143\157"
  "\154\165\155\156\163\075\062\040\156\055\162\157\167\163\075\071"
  "\040\055\055\076\012\040\040\040\040\040\040\040\040\040\040\074"
  "\157\142\152\145\143\164\040\143\154\141\163\163\075\042\107\164"
  "\153\107\162\151\144\042\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\166\151\163\151\142\154\145\042\076\124\162\165"
  "\145\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\143\141\156\055\146\157\143"
  "\165\163\042\076\106\141\154\163\145\074\057\160\162\157\160\145"
  "\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\155\141\162\147\151\156\055\163\164\141\162\164\042\076\061"
  "\062\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\155\141\162\147\151\156\055"
  "\145\156\144\042\076\061\062\074\057\160\162\157\160\145\162\164"
  "\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\155"
  "\141\162\147\151\156\055\164\157\160\042\076\061\062\074\057\160"
  "\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\155\141\162\147\151\156\055\142\157\164\164"
  "\157\155\042\076\061\062\074\057\160\162\157\160\145\162\164\171"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\162\157"
  "\167\055\163\160\141\143\151\156\147\042\076\066\074\057\160\162"
  "\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\143\157\154\165\155\156\055\163\160\141\143\151"
  "\156\147\042\076\061\062\074\057\160\162\157\160\145\162\164\171"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\074\143"
  "\150\151\154\144\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\157\142\152\145\143\164\040\143\154\141\163"
  "\163\075\042\107\164\153\114\141\142\145\154\042\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\166\151"
  "\163\151\142\154\145\042\076\124\162\165\145\074\057\160\162\157"
  "\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\143\141\156\055\146\157\143\165\163"
  "\042\076\106\141\154\163\145\074\057\160\162\157\160\145\162\164"
  "\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\155\141\162\147\151\156\055\163\164\141\162\164\042"
  "\076\061\062\074\057\160\162\157\160\145\162\164\171\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\154"
  "\141\142\145\154\042\040\164\162\141\156\163\154\141\164\141\142"
  "\154\145\075\042\171\145\163\042\076\116\157\164\151\146\151\143"
  "\141\164\151\157\156\040\151\143\157\156\040\163\151\172\145\074"
  "\057\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\170\141\154\151\147"
  "\156\042\076\060\074\057\160\162\157\160\145\162\164\171\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\057"
  "\157\142\152\145\143\164\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\160\141\143\153\151\156\147\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\154\145\146\164\055\141\164\164\141\143\150\042\076\060\074\057"
  "\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\164\157\160\055\141\164"
  "\164\141\143\150\042\076\064\074\057\160\162\157\160\145\162\164"
  "\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\057\160\141\143\153\151\156\147\076\012\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\057\143\150\151\154\144\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\074\143\150"
  "\151\154\144\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\157\142\152\145\143\164\040\143\154\141\163\163"
  "\075\042\107\164\153\123\160\151\156\102\165\164\164\157\156\042"
  "\040\151\144\075\042\154\157\147\137\151\143\157\156\137\163\151"
  "\172\145\042\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\166\151\163\151\142\154\145\042\076\124\162"
  "\165\145\074\057\160\162\157\160\145\162\164\171\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\143\141"
  "\156\055\146\157\143\165\163\042\076\124\162\165\145\074\057\160"
  "\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\150\141\154\151\147\156\042"
  "\076\145\156\144\074\057\160\162\157\160\145\162\164\171\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\151\156\160\165\164\055\160\165\162\160\157\163\145\042\076\156"
  "\165\155\142\145\162\074\057\160\162\157\160\145\162\164\171\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\141\144\152\165\163\164\155\145\156\164\042\076\154\157\147"
  "\137\151\143\157\156\137\163\151\172\145\137\141\144\152\074\057"
  "\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\143\154\151\155\142\055"
  "\162\141\164\145\042\076\061\074\057\160\162\157\160\145\162\164"
  "\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\057\157\142\152\145\143\164\076\012\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\141\143\153\151\156"
  "\147\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\154\145\146\164\055\141\164\164\141\143\150\042\076"
  "\061\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\164\157\160"
  "\055\141\164\164\141\143\150\042\076\064\074\057\160\162\157\160"
  "\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\057\160\141\143\153\151\156\147\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\074\057\143\150\151"
  "\154\144\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\143\150\151\154\144\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\157\142\152\145\143\164\040\143\154"
  "\141\163\163\075\042\107\164\153\114\141\142\145\154\042\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\166\151\163\151\142\154\145\042\076\124\162\165\145\074\057\160"
  "\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\143\141\156\055\146\157\143"
  "\165\163\042\076\106\141\154\163\145\074\057\160\162\157\160\145"
  "\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\155\141\162\147\151\156\055\163\164\141\162"
  "\164\042\076\061\062\074\057\160\162\157\160\145\162\164\171\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\154\141\142\145\154\042\040\164\162\141\156\163\154\141\164"
  "\141\142\154\145\075\042\171\145\163\042\076\116\165\155\142\145"
  "\162\040\157\146\040\156\157\164\151\146\151\143\141\164\151\157"
  "\156\163\040\164\157\040\163\150\157\167\074\057\160\162\157\160"
  "\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\170\141\154\151\147\156\042\076\060\074"
  "\057\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\057\157\142\152\145\143"
  "\164\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\141\143\153\151\156\147\076\012\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\154\145\146\164\055"
  "\141\164\164\141\143\150\042\076\060\074\057\160\162\157\160\145"
  "\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\164\157\160\055\141\164\164\141\143\150\042"
  "\076\063\074\057\160\162\157\160\145\162\164\171\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\074\057\160\141"
  "\143\153\151\156\147\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\057\143\150\151\154\144\076\012\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\143\150\151\154\144\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\157"
  "\142\152\145\143\164\040\143\154\141\163\163\075\042\107\164\153"
  "\123\160\151\156\102\165\164\164\157\156\042\040\151\144\075\042"
  "\154\157\147\137\144\151\163\160\154\141\171\137\154\151\155\151"
  "\164\042\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\166\151\163\151\142\154\145\042\076\124\162\165"
  "\145\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\143\141\156"
  "\055\146\157\143\165\163\042\076\124\162\165\145\074\057\160\162"
  "\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\150\141\154\151\147\156\042\076"
  "\145\156\144\074\057\160\162\157\160\145\162\164\171\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\151"
  "\156\160\165\164\055\160\165\162\160\157\163\145\042\076\156\165"
  "\155\142\145\162\074\057\160\162\157\160\145\162\164\171\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\141\144\152\165\163\164\155\145\156\164\042\076\154\157\147\137"
  "\144\151\163\160\154\141\171\137\154\151\155\151\164\137\141\144"
  "\152\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\143\154\151"
  "\155\142\055\162\141\164\145\042\076\061\074\057\160\162\157\160"
  "\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\166\141\154\165\145\042\076\061\060\074"
  "\057\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\057\157\142\152\145\143"
  "\164\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\141\143\153\151\156\147\076\012\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\154\145\146\164\055"
  "\141\164\164\141\143\150\042\076\061\074\057\160\162\157\160\145"
  "\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\164\157\160\055\141\164\164\141\143\150\042"
  "\076\063\074\057\160\162\157\160\145\162\164\171\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\074\057\160\141"
  "\143\153\151\156\147\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\057\143\150\151\154\144\076\012\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\143\150\151\154\144\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\157"
  "\142\152\145\143\164\040\143\154\141\163\163\075\042\107\164\153"
  "\114\141\142\145\154\042\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\166\151\163\151\142\154\145\042"
  "\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\143\141\156\055\146\157\143\165\163\042\076\106\141\154\163"
  "\145\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\155\141\162"
  "\147\151\156\055\163\164\141\162\164\042\076\061\062\074\057\160"
  "\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\154\141\142\145\154\042\040"
  "\164\162\141\156\163\154\141\164\141\142\154\145\075\042\171\145"
  "\163\042\076\117\156\154\171\040\163\150\157\167\040\156\157\164"
  "\151\146\151\143\141\164\151\157\156\163\040\146\162\157\155\040"
  "\164\157\144\141\171\074\057\160\162\157\160\145\162\164\171\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\170\141\154\151\147\156\042\076\060\074\057\160\162\157\160"
  "\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\057\157\142\152\145\143\164\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\074\160\141\143"
  "\153\151\156\147\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\154\145\146\164\055\141\164\164\141\143"
  "\150\042\076\060\074\057\160\162\157\160\145\162\164\171\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\164\157\160\055\141\164\164\141\143\150\042\076\062\074\057\160"
  "\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\057\160\141\143\153\151\156\147"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\074\057"
  "\143\150\151\154\144\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\143\150\151\154\144\076\012\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\157\142\152\145\143\164"
  "\040\143\154\141\163\163\075\042\107\164\153\123\167\151\164\143"
  "\150\042\040\151\144\075\042\163\150\157\167\137\157\156\154\171"
  "\137\164\157\144\141\171\042\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\166\151\163\151\142\154\145"
  "\042\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\143\141\156\055\146\157\143\165\163\042\076\124\162\165"
  "\145\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\150\141\154"
  "\151\147\156\042\076\145\156\144\074\057\160\162\157\160\145\162"
  "\164\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\057\157\142\152\145\143\164\076\012\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\074\160\141\143\153\151"
  "\156\147\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\154\145\146\164\055\141\164\164\141\143\150\042"
  "\076\061\074\057\160\162\157\160\145\162\164\171\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\164\157"
  "\160\055\141\164\164\141\143\150\042\076\062\074\057\160\162\157"
  "\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\057\160\141\143\153\151\156\147\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\074\057\143\150"
  "\151\154\144\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\143\150\151\154\144\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\157\142\152\145\143\164\040\143"
  "\154\141\163\163\075\042\107\164\153\114\141\142\145\154\042\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\166\151\163\151\142\154\145\042\076\124\162\165\145\074\057"
  "\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\143\141\156\055\146\157"
  "\143\165\163\042\076\106\141\154\163\145\074\057\160\162\157\160"
  "\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\155\141\162\147\151\156\055\163\164\141"
  "\162\164\042\076\061\062\074\057\160\162\157\160\145\162\164\171"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\154\141\142\145\154\042\040\164\162\141\156\163\154\141"
  "\164\141\142\154\145\075\042\171\145\163\042\076\110\151\144\145"
  "\040\047\103\154\145\141\162\040\154\157\147\047\040\143\157\156"
  "\146\151\162\155\141\164\151\157\156\040\144\151\141\154\157\147"
  "\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\170\141\154\151"
  "\147\156\042\076\060\074\057\160\162\157\160\145\162\164\171\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\057\157\142\152\145\143\164\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\160\141\143\153\151\156\147\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\154\145\146\164\055\141\164\164\141\143\150\042\076\060\074"
  "\057\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\164\157\160\055\141"
  "\164\164\141\143\150\042\076\067\074\057\160\162\157\160\145\162"
  "\164\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\057\160\141\143\153\151\156\147\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\057\143\150\151\154\144"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\074\143"
  "\150\151\154\144\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\157\142\152\145\143\164\040\143\154\141\163"
  "\163\075\042\107\164\153\123\167\151\164\143\150\042\040\151\144"
  "\075\042\150\151\144\145\137\143\154\145\141\162\137\160\162\157"
  "\155\160\164\042\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\166\151\163\151\142\154\145\042\076\124"
  "\162\165\145\074\057\160\162\157\160\145\162\164\171\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\143"
  "\141\156\055\146\157\143\165\163\042\076\124\162\165\145\074\057"
  "\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\150\141\154\151\147\156"
  "\042\076\145\156\144\074\057\160\162\157\160\145\162\164\171\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\057\157\142\152\145\143\164\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\160\141\143\153\151\156\147\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\154\145\146\164\055\141\164\164\141\143\150\042\076\061\074"
  "\057\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160"
  "\145\162\164\171\040\156\141\155\145\075\042\164\157\160\055\141"
  "\164\164\141\143\150\042\076\067\074\057\160\162\157\160\145\162"
  "\164\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\057\160\141\143\153\151\156\147\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\057\143\150\151\154\144"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\074\143"
  "\150\151\154\144\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\157\142\152\145\143\164\040\143\154\141\163"
  "\163\075\042\107\164\153\114\141\142\145\154\042\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\166\151"
  "\163\151\142\154\145\042\076\124\162\165\145\074\057\160\162\157"
  "\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\143\141\156\055\146\157\143\165\163"
  "\042\076\106\141\154\163\145\074\057\160\162\157\160\145\162\164"
  "\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\155\141\162\147\151\156\055\163\164\141\162\164\042"
  "\076\061\062\074\057\160\162\157\160\145\162\164\171\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\154"
  "\141\142\145\154\042\040\164\162\141\156\163\154\141\164\141\142"
  "\154\145\075\042\171\145\163\042\076\110\151\144\145\040\160\141"
  "\156\145\154\040\142\165\164\164\157\156\040\167\150\145\156\040"
  "\156\157\040\165\156\162\145\141\144\040\156\157\164\151\146\151"
  "\143\141\164\151\157\156\163\074\057\160\162\157\160\145\162\164"
  "\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\170\141\154\151\147\156\042\076\060\074\057\160\162"
  "\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\057\157\142\152\145\143\164\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160"
  "\141\143\153\151\156\147\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\154\145\146\164\055\141\164\164"
  "\141\143\150\042\076\060\074\057\160\162\157\160\145\162\164\171"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\164\157\160\055\141\164\164\141\143\150\042\076\070\074"
  "\057\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\057\160\141\143\153\151"
  "\156\147\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\057\143\150\151\154\144\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\143\150\151\154\144\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\074\157\142\152\145"
  "\143\164\040\143\154\141\163\163\075\042\107\164\153\123\167\151"
  "\164\143\150\042\040\151\144\075\042\150\151\144\145\137\157\156"
  "\137\162\145\141\144\042\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\166\151\163\151\142\154\145\042"
  "\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\143\141\156\055\146\157\143\165\163\042\076\124\162\165\145"
  "\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162\157"
  "\160\145\162\164\171\040\156\141\155\145\075\042\150\141\154\151"
  "\147\156\042\076\145\156\144\074\057\160\162\157\160\145\162\164"
  "\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\057\157\142\152\145\143\164\076\012\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\141\143\153\151\156"
  "\147\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\154\145\146\164\055\141\164\164\141\143\150\042\076"
  "\061\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\164\157\160"
  "\055\141\164\164\141\143\150\042\076\070\074\057\160\162\157\160"
  "\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\057\160\141\143\153\151\156\147\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\074\057\143\150\151"
  "\154\144\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\143\150\151\154\144\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\157\142\152\145\143\164\040\143\154"
  "\141\163\163\075\042\107\164\153\114\141\142\145\154\042\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\166\151\163\151\142\154\145\042\076\124\162\165\145\074\057\160"
  "\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\143\141\156\055\146\157\143"
  "\165\163\042\076\106\141\154\163\145\074\057\160\162\157\160\145"
  "\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\154\141\142\145\154\042\040\164\162\141\156"
  "\163\154\141\164\141\142\154\145\075\042\171\145\163\042\076\101"
  "\160\160\145\141\162\141\156\143\145\074\057\160\162\157\160\145"
  "\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\170\141\154\151\147\156\042\076\060\074\057"
  "\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\074\141\164\164\162\151"
  "\142\165\164\145\163\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\141\164\164\162\151\142"
  "\165\164\145\040\156\141\155\145\075\042\167\145\151\147\150\164"
  "\042\040\166\141\154\165\145\075\042\142\157\154\144\042\057\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\057\141\164\164\162\151\142\165\164\145\163\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\074\057\157"
  "\142\152\145\143\164\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\160\141\143\153\151\156\147\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\154"
  "\145\146\164\055\141\164\164\141\143\150\042\076\060\074\057\160"
  "\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\164\157\160\055\141\164\164"
  "\141\143\150\042\076\060\074\057\160\162\157\160\145\162\164\171"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\167\151\144\164\150\042\076\062\074\057\160\162\157\160"
  "\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\057\160\141\143\153\151\156\147\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\074\057\143\150\151"
  "\154\144\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\143\150\151\154\144\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\157\142\152\145\143\164\040\143\154"
  "\141\163\163\075\042\107\164\153\114\141\142\145\154\042\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042"
  "\166\151\163\151\142\154\145\042\076\124\162\165\145\074\057\160"
  "\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\143\141\156\055\146\157\143"
  "\165\163\042\076\106\141\154\163\145\074\057\160\162\157\160\145"
  "\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\155\141\162\147\151\156\055\163\164\141\162"
  "\164\042\076\061\062\074\057\160\162\157\160\145\162\164\171\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\154\141\142\145\154\042\040\164\162\141\156\163\154\141\164"
  "\141\142\154\145\075\042\171\145\163\042\076\123\150\157\167\040"
  "\151\156\040\155\145\156\165\074\057\160\162\157\160\145\162\164"
  "\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\170\141\154\151\147\156\042\076\060\074\057\160\162"
  "\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\057\157\142\152\145\143\164\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160"
  "\141\143\153\151\156\147\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\154\145\146\164\055\141\164\164"
  "\141\143\150\042\076\060\074\057\160\162\157\160\145\162\164\171"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\164\157\160\055\141\164\164\141\143\150\042\076\061\074"
  "\057\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\057\160\141\143\153\151"
  "\156\147\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\057\143\150\151\154\144\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\143\150\151\154\144\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\074\157\142\152\145"
  "\143\164\040\143\154\141\163\163\075\042\107\164\153\103\157\155"
  "\142\157\102\157\170\124\145\170\164\042\040\151\144\075\042\163"
  "\150\157\167\137\151\156\137\155\145\156\165\042\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160"
  "\162\157\160\145\162\164\171\040\156\141\155\145\075\042\166\151"
  "\163\151\142\154\145\042\076\124\162\165\145\074\057\160\162\157"
  "\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\143\141\156\055\146\157\143\165\163"
  "\042\076\106\141\154\163\145\074\057\160\162\157\160\145\162\164"
  "\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\141\143\164\151\166\145\055\151\144\042\076\163\150"
  "\157\167\055\141\154\154\074\057\160\162\157\160\145\162\164\171"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\151\164\145\155\163\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\074\151\164\145"
  "\155\040\151\144\075\042\163\150\157\167\055\141\154\154\042\040"
  "\164\162\141\156\163\154\141\164\141\142\154\145\075\042\171\145"
  "\163\042\076\101\154\154\040\156\157\164\151\146\151\143\141\164"
  "\151\157\156\163\074\057\151\164\145\155\076\012\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\151"
  "\164\145\155\040\151\144\075\042\163\150\157\167\055\165\156\162"
  "\145\141\144\042\040\164\162\141\156\163\154\141\164\141\142\154"
  "\145\075\042\171\145\163\042\076\125\156\162\145\141\144\040\156"
  "\157\164\151\146\151\143\141\164\151\157\156\163\074\057\151\164"
  "\145\155\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\057\151\164\145\155\163\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\074\057\157\142\152"
  "\145\143\164\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\160\141\143\153\151\156\147\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\154\145\146"
  "\164\055\141\164\164\141\143\150\042\076\061\074\057\160\162\157"
  "\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\164\157\160\055\141\164\164\141\143"
  "\150\042\076\061\074\057\160\162\157\160\145\162\164\171\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\057"
  "\160\141\143\153\151\156\147\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\057\143\150\151\154\144\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\074\143\150\151\154\144"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\157\142\152\145\143\164\040\143\154\141\163\163\075\042\107"
  "\164\153\114\141\142\145\154\042\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\166\151\163\151\142\154"
  "\145\042\076\124\162\165\145\074\057\160\162\157\160\145\162\164"
  "\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155"
  "\145\075\042\143\141\156\055\146\157\143\165\163\042\076\106\141"
  "\154\163\145\074\057\160\162\157\160\145\162\164\171\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074"
  "\160\162\157\160\145\162\164\171\040\156\141\155\145\075\042\154"
  "\141\142\145\154\042\040\164\162\141\156\163\154\141\164\141\142"
  "\154\145\075\042\171\145\163\042\076\102\145\150\141\166\151\157"
  "\162\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\170\141\154"
  "\151\147\156\042\076\060\074\057\160\162\157\160\145\162\164\171"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\141\164\164\162\151\142\165\164\145\163\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\141\164\164\162\151\142\165\164\145\040\156\141\155\145"
  "\075\042\167\145\151\147\150\164\042\040\166\141\154\165\145\075"
  "\042\142\157\154\144\042\057\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\057\141\164\164\162\151"
  "\142\165\164\145\163\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\057\157\142\152\145\143\164\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160\141"
  "\143\153\151\156\147\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\154\145\146\164\055\141\164\164\141"
  "\143\150\042\076\060\074\057\160\162\157\160\145\162\164\171\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\164\157\160\055\141\164\164\141\143\150\042\076\065\074\057"
  "\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\167\151\144\164\150\042"
  "\076\062\074\057\160\162\157\160\145\162\164\171\076\012\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\074\057\160\141"
  "\143\153\151\156\147\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\057\143\150\151\154\144\076\012\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\143\150\151\154\144\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\157"
  "\142\152\145\143\164\040\143\154\141\163\163\075\042\107\164\153"
  "\114\141\142\145\154\042\076\012\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\166\151\163\151\142\154\145\042"
  "\076\124\162\165\145\074\057\160\162\157\160\145\162\164\171\076"
  "\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145\075"
  "\042\143\141\156\055\146\157\143\165\163\042\076\106\141\154\163"
  "\145\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\155\141\162"
  "\147\151\156\055\163\164\141\162\164\042\076\061\062\074\057\160"
  "\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\154\141\142\145\154\042\040"
  "\164\162\141\156\163\154\141\164\141\142\154\145\075\042\171\145"
  "\163\042\076\101\146\164\145\162\040\163\150\157\167\151\156\147"
  "\040\164\150\145\040\155\145\156\165\074\057\160\162\157\160\145"
  "\162\164\171\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156"
  "\141\155\145\075\042\170\141\154\151\147\156\042\076\060\074\057"
  "\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\057\157\142\152\145\143\164"
  "\076\012\040\040\040\040\040\040\040\040\040\040\040\040\040\040"
  "\074\160\141\143\153\151\156\147\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145"
  "\162\164\171\040\156\141\155\145\075\042\154\145\146\164\055\141"
  "\164\164\141\143\150\042\076\060\074\057\160\162\157\160\145\162"
  "\164\171\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\164\157\160\055\141\164\164\141\143\150\042\076"
  "\066\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\074\057\160\141\143"
  "\153\151\156\147\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\057\143\150\151\154\144\076\012\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\143\150\151\154\144\076\012\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\074\157\142"
  "\152\145\143\164\040\143\154\141\163\163\075\042\107\164\153\103"
  "\157\155\142\157\102\157\170\124\145\170\164\042\040\151\144\075"
  "\042\141\146\164\145\162\137\155\145\156\165\137\163\150\157\167"
  "\156\042\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\160\162\157\160\145\162\164\171\040\156\141"
  "\155\145\075\042\166\151\163\151\142\154\145\042\076\124\162\165"
  "\145\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\143\141\156"
  "\055\146\157\143\165\163\042\076\106\141\154\163\145\074\057\160"
  "\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162"
  "\164\171\040\156\141\155\145\075\042\141\143\164\151\166\145\055"
  "\151\144\042\076\155\141\162\153\055\141\154\154\055\162\145\141"
  "\144\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\074\151\164"
  "\145\155\163\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\151\164\145\155\040\151\144\075"
  "\042\155\141\162\153\055\141\154\154\055\162\145\141\144\042\040"
  "\164\162\141\156\163\154\141\164\141\142\154\145\075\042\171\145"
  "\163\042\076\115\141\162\153\040\141\154\154\040\154\157\147\040"
  "\145\156\164\162\151\145\163\040\162\145\141\144\074\057\151\164"
  "\145\155\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\151\164\145\155\040\151\144\075\042"
  "\155\141\162\153\055\163\150\157\167\156\055\162\145\141\144\042"
  "\040\164\162\141\156\163\154\141\164\141\142\154\145\075\042\171"
  "\145\163\042\076\115\141\162\153\040\163\150\157\167\156\040\154"
  "\157\147\040\145\156\164\162\151\145\163\040\162\145\141\144\074"
  "\057\151\164\145\155\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\040\040\074\151\164\145\155\040\151"
  "\144\075\042\144\157\055\156\157\164\150\151\156\147\042\040\164"
  "\162\141\156\163\154\141\164\141\142\154\145\075\042\171\145\163"
  "\042\076\104\157\040\156\157\164\150\151\156\147\074\057\151\164"
  "\145\155\076\012\040\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\074\057\151\164\145\155\163\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\074\057\157\142\152"
  "\145\143\164\076\012\040\040\040\040\040\040\040\040\040\040\040"
  "\040\040\040\074\160\141\143\153\151\156\147\076\012\040\040\040"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\074\160\162"
  "\157\160\145\162\164\171\040\156\141\155\145\075\042\154\145\146"
  "\164\055\141\164\164\141\143\150\042\076\061\074\057\160\162\157"
  "\160\145\162\164\171\076\012\040\040\040\040\040\040\040\040\040"
  "\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171"
  "\040\156\141\155\145\075\042\164\157\160\055\141\164\164\141\143"
  "\150\042\076\066\074\057\160\162\157\160\145\162\164\171\076\012"
  "\040\040\040\040\040\040\040\040\040\040\040\040\040\040\074\057"
  "\160\141\143\153\151\156\147\076\012\040\040\040\040\040\040\040"
  "\040\040\040\040\040\074\057\143\150\151\154\144\076\012\040\040"
  "\040\040\040\040\040\040\040\040\074\057\157\142\152\145\143\164"
  "\076\012\040\040\040\040\040\040\040\040\040\040\074\160\141\143"
  "\153\151\156\147\076\012\040\040\040\040\040\040\040\040\040\040"
  "\040\040\074\160\162\157\160\145\162\164\171\040\156\141\155\145"
  "\075\042\145\170\160\141\156\144\042\076\124\162\165\145\074\057"
  "\160\162\157\160\145\162\164\171\076\012\040\040\040\040\040\040"
  "\040\040\040\040\040\040\074\160\162\157\160\145\162\164\171\040"
  "\156\141\155\145\075\042\146\151\154\154\042\076\124\162\165\145"
  "\074\057\160\162\157\160\145\162\164\171\076\012\040\040\040\040"
  "\040\040\040\040\040\040\040\040\074\160\162\157\160\145\162\164"
  "\171\040\156\141\155\145\075\042\160\157\163\151\164\151\157\156"
  "\042\076\061\074\057\160\162\157\160\145\162\164\171\076\012\040"
  "\040\040\040\040\040\040\040\040\040\074\057\160\141\143\153\151"
  "\156\147\076\012\040\040\040\040\040\040\040\040\074\057\143\150"
  "\151\154\144\076\012\040\040\040\040\040\040\074\057\157\142\152"
  "\145\143\164\076\012\040\040\040\040\074\057\143\150\151\154\144"
  "\076\012\040\040\040\040\074\141\143\164\151\157\156\055\167\151"
  "\144\147\145\164\163\076\012\040\040\040\040\040\040\074\141\143"
  "\164\151\157\156\055\167\151\144\147\145\164\040\162\145\163\160"
  "\157\156\163\145\075\042\055\061\061\042\076\150\145\154\160\137"
  "\142\165\164\164\157\156\074\057\141\143\164\151\157\156\055\167"
  "\151\144\147\145\164\076\012\040\040\040\040\040\040\074\141\143"
  "\164\151\157\156\055\167\151\144\147\145\164\040\162\145\163\160"
  "\157\156\163\145\075\042\055\065\042\076\143\154\157\163\145\137"
  "\142\165\164\164\157\156\074\057\141\143\164\151\157\156\055\167"
  "\151\144\147\145\164\076\012\040\040\040\040\074\057\141\143\164"
  "\151\157\156\055\167\151\144\147\145\164\163\076\012\040\040\074"
  "\057\157\142\152\145\143\164\076\012\074\057\151\156\164\145\162"
  "\146\141\143\145\076\012\000\000\050\165\165\141\171\051\170\146"
  "\143\145\057\000\004\000\000\000\057\000\000\000\000\000\000\000"
  "\156\157\164\151\146\171\144\057\005\000\000\000\160\141\156\145"
  "\154\055\160\154\165\147\151\156\057\000\000\000\001\000\000\000"
  "" };

static GStaticResource static_resource = { notification_plugin_settings_ui_resource_data.data, sizeof (notification_plugin_settings_ui_resource_data.data) - 1 /* nul terminator */, NULL, NULL, NULL };

G_MODULE_EXPORT
GResource *notification_plugin_settings_ui_get_resource (void);
GResource *notification_plugin_settings_ui_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}

G_MODULE_EXPORT
void notification_plugin_settings_ui_unregister_resource (void);
void notification_plugin_settings_ui_unregister_resource (void)
{
  g_static_resource_fini (&static_resource);
}

G_MODULE_EXPORT
void notification_plugin_settings_ui_register_resource (void);
void notification_plugin_settings_ui_register_resource (void)
{
  g_static_resource_init (&static_resource);
}
